@@ -22,6 +22,7 @@ class StructuredEmbeddingEnsmallen(SiameseEnsmallen):
         dtype: str = "f32",
         random_state: int = 42,
         verbose: bool = False,
+        ring_bell: bool = False,
         enable_cache: bool = False
     ):
         """Create new Structured Embedding method.
@@ -59,6 +60,8 @@ class StructuredEmbeddingEnsmallen(SiameseEnsmallen):
             Random state to reproduce the embeddings.
         verbose: bool = False
             Whether to show loading bars.
+        ring_bell: bool = False,
+            Whether to play a sound when embedding completes.
         enable_cache: bool = False
             Whether to enable the cache, that is to
             store the computed embedding.
@@ -75,6 +78,7 @@ class StructuredEmbeddingEnsmallen(SiameseEnsmallen):
             dtype=dtype,
             random_state=random_state,
             verbose=verbose,
+            ring_bell=ring_bell,
             enable_cache=enable_cache,
         )
 
